@@ -167,13 +167,13 @@ check_using_gnu_ld () {
 }
 
 check_cflags () {
-  cflags_debug=
-  cflags_optimize="-O2"
-  cflags_include=
-  cflags_user=
-  cflags_compiler=
-  cflags_system=
-  cflags_application=
+  cflags_debug=${CFLAGS_DEBUG:-}
+  cflags_optimize=${CFLAGS_OPTIMIZE:--O2}
+  cflags_include=${CFLAGS_INCLUDE}
+  cflags_user=${CFLAGS_USER}
+  cflags_compiler=${CFLAGS_COMPILER}
+  cflags_system=${CFLAGS_SYSTEM}
+  cflags_application=${CFLAGS_APPLICATION}
 
   if [ "${_MKCONFIG_USING_GCC}" = Y ]; then
     puts "set gcc flags" >&9
@@ -210,8 +210,8 @@ check_cflags () {
           esac
         fi
         ;;
-      FreeBSD)
-        # FreeBSD has many packages that get installed in /usr/local
+      DragonFly|FreeBSD|OpenBSD)
+        # *BSD has many packages that get installed in /usr/local
         doappend cflags_include " -I/usr/local/include"
         ;;
       HP-UX)
@@ -257,11 +257,11 @@ check_cflags () {
         ;;
   esac
 
+  _dogetconf
+
   # largefile flags
   doappend cflags_system " $lfccflags"
 
-  _dogetconf
-
   # plain CFLAGS will be interpreted as the user's cflags
   _read_option CFLAGS ""
   cflags_user=$CFLAGS
@@ -365,12 +365,12 @@ check_ldflags () {
     TCC=gcc
   fi
 
-  ldflags_debug=
-  ldflags_optimize=
-  ldflags_user=
-  ldflags_compiler=
-  ldflags_system=
-  ldflags_application=
+  ldflags_debug=${LDFLAGS_DEBUG:-}
+  ldflags_optimize=${LDFLAGS_OPTIMIZE:-}
+  ldflags_user=${LDFLAGS_USER:-}
+  ldflags_compiler=${LDFLAGS_COMPILER:-}
+  ldflags_system=${LDFLAGS_SYSTEM:-}
+  ldflags_application=${LDFLAGS_APPLICATION:-}
 
   doappend ldflags_system " $lfldflags"
 
@@ -447,9 +447,9 @@ check_ldflags () {
 check_libs () {
   _dogetconf
 
-  ldflags_libs_user=
-  ldflags_libs_application=
-  ldflags_libs_system=
+  ldflags_libs_user=${LDFLAGS_LIBS_USER:-}
+  ldflags_libs_application=${LDFLAGS_LIBS_APPLICATION:-}
+  ldflags_libs_system=${LDFLAGS_LIBS_SYSTEM:-}
 
   TCC=${CC}
   if [ "${_MKCONFIG_USING_GCC}" = Y ]; then
@@ -484,7 +484,7 @@ check_shcflags () {
   check_cflags_shared
 }
 
-check_shcflags () {
+check_cflags_shared () {
   printlabel CFLAGS_SHARED "shared library cflags"
 
   cflags_shared=""
@@ -716,7 +716,7 @@ check_findconfig () {
   sp=
   incchk=
   pp=`puts $PATH | sed 's/:/ /g'`
-  for p in $HOME/local/lib /usr/local/lib /opt/local/lib $pp; do
+  for p in $pp $HOME/local/lib /usr/local/lib /opt/local/lib; do
     td=$p
     case $p in
       */bin)
@@ -742,3 +742,40 @@ check_findconfig () {
     setdata ${_MKCONFIG_PREFIX} config_${cfile} N
   fi
 }
+
+check_findpc () {
+  name=$1
+  cfile=$2
+  printlabel FINDPC "Search for: ${cfile}"
+  sp=
+  incchk=
+  pp=`puts $PATH | sed 's/:/ /g'`
+  for p in $pp $HOME/local/lib /usr/local/lib \
+      /opt/local/lib /usr/lib/x86_64-linux-gnu; do
+    td=$p
+    case $p in
+      */bin)
+        dosubst td '/bin$' '/lib'
+        ;;
+    esac
+
+    doappend td /pkgconfig
+    if [ -d $td ]; then
+      if [ -f "$td/$cfile.sh" ]; then
+        puts "found: ${td}" >&9
+        sp=$td
+        break
+      fi
+    fi
+  done
+
+  if [ z$sp != z ]; then
+    printyesno_val $name yes
+    setdata ${_MKCONFIG_PREFIX} pc_${cfile} Y
+    setdata ${_MKCONFIG_PREFIX} pc_path_${cfile} $sp/$cfile
+    . $sp/$cfile.sh ; # load the environment variables
+  else
+    printyesno_val $name no
+    setdata ${_MKCONFIG_PREFIX} pc_${cfile} N
+  fi
+}
